/*
	Benny's tlib.h/tlib.c
        Based upon tlib, short form.
*/
typedef struct {
    float x,y,z;
    float w;
    float s,t;
    float r,g,b;
    float a;
} Vertex3D;

/*
       From tlib.c, SF
*/

typedef FxU32 Palette[256];

typedef struct {
  FxU8  yRGB[16];
  FxI16 iRGB[4][3];
  FxI16 qRGB[4][3];
  FxU32 packed_data[12];
} NCCTable;

typedef union {
    Palette  palette;
    NCCTable nccTable;
} TextureTable;

typedef struct {
    GrTexInfo      info;
    GrTexTable_t   tableType;
    TextureTable   tableData;
} Texture;

#define NO_TABLE ((GrTexTable_t)(~0))

static GrTexTable_t texTableType( GrTextureFormat_t format )
{
    GrTexTable_t rv = (GrTexTable_t)NO_TABLE;
    switch( format ) {
    case GR_TEXFMT_YIQ_422:
    case GR_TEXFMT_AYIQ_8422:
	rv = GR_TEXTABLE_NCC0;
	break;
    case GR_TEXFMT_P_8:
    case GR_TEXFMT_AP_88:
	rv = GR_TEXTABLE_PALETTE;
	break;
    }
    return rv;
}

FxU32 info_width, info_height; // Added - Benny.

int LoadTexture(const char *filename, GrTexInfo *info,
	GrTexTable_t *tableType, void *table)
{
    Gu3dfInfo tdfInfo;
    int rv = 0;

    // modif:
    if (!( filename )) quit("LoadTexture failed");
    if (!( info )) quit("LoadTexture failed");
    if (!( tableType )) quit("LoadTexture failed");
    if (!( table )) quit("LoadTexture failed");

    if ( gu3dfGetInfo( filename, &tdfInfo ) ) {
	tdfInfo.data = malloc( tdfInfo.mem_required );
	if (!( tdfInfo.data )) quit("LoadTexture failed");

	if ( gu3dfLoad( filename, &tdfInfo ) ) {
	    info->smallLod    = tdfInfo.header.small_lod;
	    info->largeLod    = tdfInfo.header.large_lod;
	    info->aspectRatio = tdfInfo.header.aspect_ratio;
	    info->format      = tdfInfo.header.format;
	    info->data        = tdfInfo.data;

	    // Added - Benny.
	    info_width      = tdfInfo.header.width;
	    info_height     = tdfInfo.header.height;
	    // -

	    *tableType = texTableType( info->format );
	    switch( *tableType ) {
	    case GR_TEXTABLE_NCC0:
	    case GR_TEXTABLE_NCC1:
	    case GR_TEXTABLE_PALETTE:
		memcpy( table, &(tdfInfo.table), sizeof( TextureTable ) );
		break;
	    default:
		break;
	    }
	    rv = 1;
	}
    }
    return rv;
}
